# yet-another-imod-wrapper

[![License](https://img.shields.io/pypi/l/yet-another-imod-wrapper.svg?color=green)](https://github.com/alisterburt/yet-another-imod-wrapper/raw/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/yet-another-imod-wrapper.svg?color=green)](https://pypi.org/project/yet-another-imod-wrapper)
[![Python Version](https://img.shields.io/pypi/pyversions/yet-another-imod-wrapper.svg?color=green)](https://python.org)
[![CI](https://github.com/alisterburt/yet-another-imod-wrapper/actions/workflows/ci.yml/badge.svg)](https://github.com/alisterburt/yet-another-imod-wrapper/actions/workflows/ci.yml)
[![codecov](https://codecov.io/gh/alisterburt/yet-another-imod-wrapper/branch/main/graph/badge.svg)](https://codecov.io/gh/alisterburt/yet-another-imod-wrapper)

yet another IMOD wrapper
